@@ -2,7 +2,22 @@
 /**
  * 管理側のページを管理するコントローラー。
  *
- * LICENSE: ライセンスに関する情報
+ * Copyright (c) 2010-2011 SetucoCMS Project.(http://sourceforge.jp/projects/setucocms)
+ * All Rights Reserved.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  * @category    Setuco
  * @package     Admin
@@ -197,21 +212,29 @@ class Admin_PageController extends Setuco_Controller_Action_AdminAbstract
         if (!$this->_isValidSearchForm($searchForm, $this->_getAllParams())) {
             $this->_setParam('searchForm', $searchForm);
         }
-        $keyword = $searchForm->getValue('query');
 
+        $keyword = $searchForm->getValue('query');
+        $sortColumn = $this->_getParam('sort', self::DEFAULT_SORT_COLUMN);
+        $sortOrder = $this->_getParam('order', self::DEFAULT_ORDER);
+
+        //検索パラメーターの引数オブジェクトを生成する
+        $keyword = $searchForm->getValue('query');
         $targets = (array) $searchForm->getValue('targets');
         $refinements = $this->_makeRefinements($searchForm);
-
-        $pages = $this->_pageService->searchPages(
+        $pageParamIns = new Common_Model_Page_Param(
             $keyword,
             $this->_getPageNumber(),
             $this->_getPageLimit(),
             $targets,
             $refinements,
-            self::DEFAULT_SORT_COLUMN,
-            self::DEFAULT_ORDER
+            $sortColumn,
+            $sortOrder
         );
 
+        $pages = $this->_pageService->searchPages($pageParamIns);
+
+        $this->view->params = $this->_makeQueryString($targets);
+
         $pages = self::adjustPages($pages);
 
         $this->_helper->viewRenderer('index');
@@ -220,12 +243,31 @@ class Admin_PageController extends Setuco_Controller_Action_AdminAbstract
         $this->view->categoryForm = $this->_createCategoryForm();
         $this->view->statusForm = new Setuco_Form_Page_StatusUpdate();
         $this->setPagerForView(
-            $this->_pageService->countPagesByKeyword(
-                $keyword, $targets, $refinements
-            )
+            $this->_pageService->countPagesByKeyword($pageParamIns)
         );
-        $this->view->isSearched = true;
+
         $this->_pageTitle = "ページの編集・削除";
+
+    }
+
+    /**
+     * 検索後のソートボタンのリンクURLに使うため、検索された条件のURLパラメータを取得します。
+     *
+     * @param array   $targets _searchOperationメソッドで取得したパラメータ'targets'の配列
+     * @return string /query/~~(/targets/~~){3}/category_id/~~/account_id/~~/status/~~
+     * @author akitsukada
+     */
+    private function _makeQueryString($targets)
+    {
+        $params = $this->getRequest()->getParams();
+        $paramsInfo = '/query/' . $params['query'];
+        foreach ($targets as $column) {
+            $paramsInfo .= '/targets/' . $column;
+        }
+        $paramsInfo .= '/category_id/' . $params['category_id'];
+        $paramsInfo .= '/account_id/' . $params['account_id'];
+        $paramsInfo .= '/status/' . $params['status'];
+        return $paramsInfo;
     }
 
     /**
